@@ -28,6 +28,7 @@ from navis.transforms.templates import TemplateBrain
 __all__ = ['FCWB', 'IBN', 'IBNWB', 'IS2', 'JFRC2', 'T1', 'Dmel', 'DsecI',
            'Dsim', 'Dvir', 'JFRC2013', 'JFRC2013DS', 'JRC2018F', 'JRC2018U',
            'JRCFIB2018F', 'JRCFIB2018Fraw', 'JRCFIB2018Fum', 'JRCVNC2018F',
+           'JRCFIB2022M',
            'JRCVNC2018M',
            'JRCVNC2018U',
            'VNCIS1',
@@ -66,14 +67,19 @@ class FlyTemplateBrain(TemplateBrain):
         return self.__str__()
 
     def __str__(self):
+        units = getattr(self, 'units', 'units NA')
+
+        if isinstance(units, list):
+            units = units[0]
+
         if getattr(self, 'boundingbox'):
             bbox = f"""\
-            Bounding box ({self.units[0] if getattr(self, 'units') else 'NA'}):
+            Bounding box ({units}):
               x = {self.boundingbox[0]}, y = {self.boundingbox[2]}, z = {self.boundingbox[4]},
               x = {self.boundingbox[1]}, y = {self.boundingbox[3]}, z = {self.boundingbox[5]},"""
         else:
             bbox = f"""\
-            Bounding box ({self.units[0] if getattr(self, 'units') else 'units NA'}):
+            Bounding box ({units}):
               NA"""
 
         if getattr(self, 'dims'):
@@ -546,7 +552,7 @@ JRC2018U = _JRC2018U(**template_meta['JRC2018U'])
 
 
 class _JRCFIB2018F(FlyTemplateBrain):
-    """JRCFIB2018F aka hemibrain dataset.
+    """JRCFIB2018F aka "hemibrain" dataset.
 
     The JRCFIB2018F reference brain is a stitched FIB SEM volume completed at
     HHMI Janelia Research Campus in 2018.
@@ -658,6 +664,23 @@ class _JRCFIB2018Fraw(_JRCFIB2018F):
 
 JRCFIB2018Fraw = _JRCFIB2018Fraw(**template_meta['JRCFIB2018Fraw'])
 
+class _JRCFIB2022M(FlyTemplateBrain):
+    """JRCFIB2022M aka "male CNS" dataset.
+
+    The JRCFIB2022M EM volume is a whole male CNS (brain + VNC) currently being
+    generated by FlyEM at HHMI Janelia Research Campus. At this point, only the
+    brain portion of the volume is available.
+
+    The mesh was generated from a point cloud of automaticaly detected synaptic
+    t-bars.
+
+    The JRCFIB2022Mraw reference brain is uncalibrated (i.e. has units of raw
+    pixels), whereas JRCFIB2022M and JRCFIB2022Mum have units of nanometers
+    and microns with 8x8x8nm isotropic voxels, respectively.
+
+    """
+
+JRCFIB2022M = _JRCFIB2022M(**template_meta['JRCFIB2022M'])
 
 class _JRCVNC2018F(FlyTemplateBrain):
     """JRC2018 reference ventral nerve chords.
@@ -963,6 +986,7 @@ def register_templates():
                  JRCFIB2018Fraw, JRCVNC2018F, JRCVNC2018U, JRCVNC2018M, VNCIS1,
                  FAFB14, FAFB,
                  FLYWIRE,
+                 JRCFIB2022M,
                  FANC, DmelL1CNS_Seymour, COURT2017VNS, COURT2018VNS]
 
     for tmp in templates:
